# COMPAS Discrete Element Models

Discrete Element Models for Modern Masonry Design and Historic Masonry Assessment

## Installation

Stable releases can be installed from PyPI.

```bash
pip install compas_dem
```

To install the latest version for development, do:

```bash
git clone https://github.com/blockresearchgroup/compas_dem.git
cd compas_dem
pip install -e ".[dev]"
```

## Documentation

For further "getting started" instructions, a tutorial, examples, and an API reference,
please check out the online documentation here: [COMPAS Discrete Element Models docs](https://blockresearchgroup.github.io/compas_dem)

## Issue Tracker

If you find a bug or if you have a problem with running the code, please file an issue on the [Issue Tracker](https://github.com/blockresearchgroup/compas_dem/issues).
